import{p as e,b as o}from"./p-0f50db55.js";export{s as setNonce}from"./p-0f50db55.js";import{g as t}from"./p-e1255160.js";(()=>{const s=import.meta.url,o={};return""!==s&&(o.resourcesUrl=new URL(".",s).href),e(o)})().then((async s=>(await t(),o([["p-72c8cb5f",[[0,"django-hstore-widget",{json:[1025],field_name:[1],cols:[2],rows:[2],delete_svg_src:[1],add_svg_src:[1],edit_svg_src:[1],output_render_type:[32],mounted:[32],close_textarea_clickable:[32],__json:[32]},null,{json:["jsonWatcher"]}]]]],s))));